# -*- coding: utf-8 -*-
##################################################
# This file is part of WAPT Enterprise
# All right reserved, (c) Tranquil IT Systems 2024
# For more information please refer to
# https://wapt.tranquil.it/store/licences.html
##################################################
from setuphelpers import *


def update_package():
    # Declaring local variables
    package_updated = False
    proxies = get_proxies()
    if not proxies:
        proxies = get_proxies_from_wapt_console()
    app_name = control.name

    api_url = "https://api.github.com/repos/laurent22/joplin/releases/latest"

    releases_dict = wgets(api_url, proxies=proxies, as_json=True)
    version = releases_dict["tag_name"].replace('v', '')

    os_dict = {
        "windows-all": f"Joplin-Setup-{version}.exe",
        "linux-x64": f"Joplin-{version}.AppImage",
        "darwin-x64": f"Joplin-{version}.dmg",
        "darwin-arm": f"Joplin-{version}-arm64.dmg",
    }

    os_type = control.target_os + "-" + ensure_list(control.architecture)[0]

    for asset in releases_dict["assets"]:
        if asset["name"].lower() == os_dict[os_type].lower():
            download_url = asset["browser_download_url"]
            latest_bin = asset["name"].replace('DMG', 'dmg')
            latest_bin_extension = latest_bin.rsplit('.', 1)[-1]
            break

    # Downloading latest binaries
    print(f"Latest {app_name} version is: {version}")
    print(f"Download URL is: {download_url}")
    if not isfile(latest_bin):
        print(f"Downloading: {latest_bin}")
        wget(download_url, latest_bin, proxies=proxies)
    else:
        print(f"Binary is present: {latest_bin}")

    # Changing version of the package
    if Version(version) > Version(control.get_software_version()):
        print(f"Software version updated (from: {control.get_software_version()} to: {Version(version)})")
        package_updated = True
    else:
        print(f"Software version up-to-date ({Version(version)})")

    for f in glob.glob(f'*.{latest_bin_extension}'):
        if f != latest_bin:
            remove_file(f)

    control.set_software_version(version)
    control.save_control_to_wapt()

    return package_updated